
# cherry.distributions


::: cherry.distributions.Categorical
    selection:
      members:
        - mode

::: cherry.distributions.Normal
    selection:
      members:
        - mode

::: cherry.distributions.TanhNormal
    selection:
      members:
        - __init__
        - mode
        - mean
        - sample_and_log_prob
        - rsample_and_log_prob

::: cherry.distributions.Reparameterization
    selection:
      members:
        - __init__

::: cherry.distributions.ActionDistribution
    selection:
      members:
        - __init__
